//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Types/AxisProperty.cpp
//! @brief     Implements class AxisProperty
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2022
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/Model/Types/AxisProperty.h"
#include "Base/Util/Assert.h"
#include "GUI/Model/XML/Serializer.h"

void AxisProperty::initNbins(const QString& label, const QString& tooltip, uint n,
                             const variant<QString, Unit>& unit)
{
    m_nbins.init(label, tooltip, n, unit, "nbins");
}


void AxisProperty::initMin(const QString& label, const QString& tooltip, double value,
                           const variant<QString, Unit>& unit, uint decimals /*= 3*/,
                           const RealLimits& limits /*= RealLimits::nonnegative()*/)
{
    m_min.init(label, tooltip, value, unit, decimals, limits, "min");
}

void AxisProperty::initMax(const QString& label, const QString& tooltip, double value,
                           const variant<QString, Unit>& unit, uint decimals /*= 3*/,
                           const RealLimits& limits /*= RealLimits::nonnegative()*/)
{
    m_max.init(label, tooltip, value, unit, decimals, limits, "max");
}

void AxisProperty::serialize(Serializer& s)
{
    s.assertVersion(0);
    s.rw(m_nbins);
    s.rw(m_min);
    s.rw(m_max);
}

std::unique_ptr<FixedBinAxis> AxisProperty::createAxis(double scaleFactor) const
{
    return std::make_unique<FixedBinAxis>(std::string(), m_nbins, m_min * scaleFactor,
                                          m_max * scaleFactor);
}
